pub struct FloraServiceClient<Stub = Channel<FloraServiceRequest, FloraServiceResponse>>(/* private fields */);Expand description
The client stub that makes RPC calls to the server. All request methods return Futures.
Implementations
Sourceimpl FloraServiceClient
impl FloraServiceClient
Sourcepub fn new<T>(
config: Config,
transport: T,
) -> NewClient<Self, RequestDispatch<FloraServiceRequest, FloraServiceResponse, T>>
pub fn new<T>( config: Config, transport: T, ) -> NewClient<Self, RequestDispatch<FloraServiceRequest, FloraServiceResponse, T>>
Returns a new client stub that sends requests over the given transport.
Sourceimpl<Stub> FloraServiceClient<Stub>
impl<Stub> FloraServiceClient<Stub>
Sourcepub fn ping(
&self,
ctx: Context,
) -> impl Future<Output = Result<String, RpcError>> + '_
pub fn ping( &self, ctx: Context, ) -> impl Future<Output = Result<String, RpcError>> + '_
Pings the server. Can be used to check the server is alive.
A server is expected to respond with PONG.
Sourcepub fn add_record(
&self,
ctx: Context,
record_params: RecordParams,
) -> impl Future<Output = Result<OmryResult<RecordId>, RpcError>> + '_
pub fn add_record( &self, ctx: Context, record_params: RecordParams, ) -> impl Future<Output = Result<OmryResult<RecordId>, RpcError>> + '_
Adds a record to flora.
Sourcepub fn add_many_records(
&self,
ctx: Context,
records: Vec<RecordParams>,
) -> impl Future<Output = Result<OmryResult<RecordIds>, RpcError>> + '_
pub fn add_many_records( &self, ctx: Context, records: Vec<RecordParams>, ) -> impl Future<Output = Result<OmryResult<RecordIds>, RpcError>> + '_
Adds multiple records to flora.
Sourcepub fn count(
&self,
ctx: Context,
) -> impl Future<Output = Result<OmryResult<i64>, RpcError>> + '_
pub fn count( &self, ctx: Context, ) -> impl Future<Output = Result<OmryResult<i64>, RpcError>> + '_
Returns the count of records in the database.
Sourcepub fn get_records(
&self,
ctx: Context,
record_ids: RecordIds,
) -> impl Future<Output = Result<OmryResult<Arc<Vec<Record>>>, RpcError>> + '_
pub fn get_records( &self, ctx: Context, record_ids: RecordIds, ) -> impl Future<Output = Result<OmryResult<Arc<Vec<Record>>>, RpcError>> + '_
Gets records matching the given IDs.
Sourcepub fn get_all_records(
&self,
ctx: Context,
) -> impl Future<Output = Result<OmryResult<Arc<Vec<Record>>>, RpcError>> + '_
pub fn get_all_records( &self, ctx: Context, ) -> impl Future<Output = Result<OmryResult<Arc<Vec<Record>>>, RpcError>> + '_
Gets all records in the Omry database.
Sourcepub fn get_all_records_meta(
&self,
ctx: Context,
) -> impl Future<Output = Result<OmryResult<Vec<RecordMeta>>, RpcError>> + '_
pub fn get_all_records_meta( &self, ctx: Context, ) -> impl Future<Output = Result<OmryResult<Vec<RecordMeta>>, RpcError>> + '_
Gets the metadata (all fields except document)
for all records in the Omry database.
Sourcepub fn delete_record(
&self,
ctx: Context,
record_id: RecordId,
) -> impl Future<Output = Result<OmryResult<usize>, RpcError>> + '_
pub fn delete_record( &self, ctx: Context, record_id: RecordId, ) -> impl Future<Output = Result<OmryResult<usize>, RpcError>> + '_
Deletes record with the given ID.
Sourcepub fn search(
&self,
ctx: Context,
search_params: SearchParametersWrapper,
) -> impl Future<Output = Result<OmryResult<SearchResponse>, RpcError>> + '_
pub fn search( &self, ctx: Context, search_params: SearchParametersWrapper, ) -> impl Future<Output = Result<OmryResult<SearchResponse>, RpcError>> + '_
Searches Omry’s Typesense instance.